You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@opennlp.apache.org by bg...@apache.org on 2012/03/23 19:26:40 UTC

svn commit: r1304545 - in /opennlp/sandbox/opennlp-similarity/src: main/java/opennlp/tools/similarity/apps/ main/java/opennlp/tools/textsimilarity/chunker2matcher/ test/java/opennlp/tools/similarity/apps/ test/java/opennlp/tools/textsimilarity/ test/ja...

Author: bgalitsky
Date: Fri Mar 23 18:26:39 2012
New Revision: 1304545

URL: http://svn.apache.org/viewvc?rev=1304545&view=rev
Log:
OPENNLP-420 
to speed up similarity computation, store parsing results in a hash, so that if a sentence has been parsed, chunked and prepared for matching once, we store it in a hash. 
when the Processor is instantiated, hash is deserialized. When the processor is closed, this hash is serialized.

Added:
    opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/textsimilarity/chunker2matcher/ParserCacheSerializer.java
Modified:
    opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/HitBaseComparable.java
    opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/SearchResultsProcessor.java
    opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/SpeechRecognitionResultsProcessor.java
    opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/textsimilarity/chunker2matcher/ParserChunker2MatcherProcessor.java
    opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/similarity/apps/SearchResultsProcessorTest.java
    opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/similarity/apps/SpeechRecognitionResultsProcessorTest.java
    opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/SyntMatcherTest.java
    opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/chunker2matcher/ParserChunker2MatcherProcessorTest.java
    opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/chunker2matcher/PhraseNodeTest.java

Modified: opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/HitBaseComparable.java
URL: http://svn.apache.org/viewvc/opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/HitBaseComparable.java?rev=1304545&r1=1304544&r2=1304545&view=diff
==============================================================================
--- opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/HitBaseComparable.java (original)
+++ opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/HitBaseComparable.java Fri Mar 23 18:26:39 2012
@@ -3,7 +3,7 @@ package opennlp.tools.similarity.apps;
 import java.util.Comparator;
 
 public class HitBaseComparable implements Comparator<HitBase>{
-	@Override
+	//@Override
 	public int compare(HitBase o1, HitBase o2) {
 		return (o1.getGenerWithQueryScore()>o2.getGenerWithQueryScore() ? -1 : (o1==o2 ? 0 : 1));
 	}

Modified: opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/SearchResultsProcessor.java
URL: http://svn.apache.org/viewvc/opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/SearchResultsProcessor.java?rev=1304545&r1=1304544&r2=1304545&view=diff
==============================================================================
--- opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/SearchResultsProcessor.java (original)
+++ opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/SearchResultsProcessor.java Fri Mar 23 18:26:39 2012
@@ -30,6 +30,7 @@ import opennlp.tools.textsimilarity.chun
 public class SearchResultsProcessor extends BingWebQueryRunner {
 	private static Logger LOG = Logger.getLogger("opennlp.tools.similarity.apps.SearchResultsProcessor");
 	private ParseTreeChunkListScorer parseTreeChunkListScorer = new ParseTreeChunkListScorer();
+	ParserChunker2MatcherProcessor sm ;
 
 	/*
 	 * Takes Bing API search results and calculates the parse tree similarity between the question and each snippet.
@@ -44,7 +45,7 @@ public class SearchResultsProcessor exte
 			return ans.calculateMatchScoreResortHits(resp, searchQuery);		
 		} */
 		List<HitBase> newHitList =	new ArrayList<HitBase>();
-		ParserChunker2MatcherProcessor sm = ParserChunker2MatcherProcessor.getInstance();
+		sm = ParserChunker2MatcherProcessor.getInstance();
 
 		for(HitBase hit: resp.getHits()){
 			String snapshot = hit.getAbstractText().replace("<b>...</b>", ". ").replace("<b>", "").replace("</b>","");
@@ -74,6 +75,10 @@ public class SearchResultsProcessor exte
 
 		return resp; 
 	}
+	
+	public void close(){
+		sm.close();
+	}
 
 	public List<HitBase> runSearch(String query) {
 		BingResponse resp = null, // obtained from bing

Modified: opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/SpeechRecognitionResultsProcessor.java
URL: http://svn.apache.org/viewvc/opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/SpeechRecognitionResultsProcessor.java?rev=1304545&r1=1304544&r2=1304545&view=diff
==============================================================================
--- opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/SpeechRecognitionResultsProcessor.java (original)
+++ opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/similarity/apps/SpeechRecognitionResultsProcessor.java Fri Mar 23 18:26:39 2012
@@ -31,6 +31,7 @@ import opennlp.tools.textsimilarity.chun
 public class SpeechRecognitionResultsProcessor extends BingWebQueryRunner {
 	private static Logger LOG = Logger.getLogger("opennlp.tools.similarity.apps.SpeechRecognitionResultsProcessor");
 	private ParseTreeChunkListScorer parseTreeChunkListScorer = new ParseTreeChunkListScorer();
+	ParserChunker2MatcherProcessor sm;
 
 	/**
 	 * Gets an expression and tries to find it on the web. If search results are syntactically similar to this phrase, then 
@@ -42,7 +43,7 @@ public class SpeechRecognitionResultsPro
 	 */
 	private	double calculateTotalMatchScoreForHits(BingResponse resp, String searchQuery){
 		
-		ParserChunker2MatcherProcessor sm = ParserChunker2MatcherProcessor.getInstance();
+		sm = ParserChunker2MatcherProcessor.getInstance();
 		double totalMatchScore = 0;
 		for(HitBase hit: resp.getHits()){
 			String snapshot = hit.getAbstractText().replace("<b>...</b>", ". ").replace("<b>", "").replace("</b>","");
@@ -64,9 +65,14 @@ public class SpeechRecognitionResultsPro
 			 totalMatchScore+=score;
 			
 		}
+		
 		return  totalMatchScore; 
 	}
 	
+	public void close(){
+		sm.close();
+	}
+	
 	/**
 	 * phrase meaningfulness assessment function which takes a list of phrases which are speech recognition results and 
 	 * re-ranks these phrases according to the meaningfulness score which is determined by 'calculateTotalMatchScoreForHits'

Added: opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/textsimilarity/chunker2matcher/ParserCacheSerializer.java
URL: http://svn.apache.org/viewvc/opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/textsimilarity/chunker2matcher/ParserCacheSerializer.java?rev=1304545&view=auto
==============================================================================
--- opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/textsimilarity/chunker2matcher/ParserCacheSerializer.java (added)
+++ opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/textsimilarity/chunker2matcher/ParserCacheSerializer.java Fri Mar 23 18:26:39 2012
@@ -0,0 +1,97 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package opennlp.tools.textsimilarity.chunker2matcher;
+
+import java.io.FileInputStream;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.ObjectInputStream;
+import java.io.ObjectOutputStream;
+import java.util.Map;
+
+
+public class ParserCacheSerializer {
+	private static String RESOURCE_DIR = "resources/";
+	public static String parseCacheFileName = "sentence_parseObject.dat";
+	
+	public static void writeObject(Object objectToSerialize)
+	{
+		String filename =  RESOURCE_DIR + parseCacheFileName;
+		FileOutputStream fos = null;
+		ObjectOutputStream out = null;
+		try
+		{
+			fos = new FileOutputStream(filename);
+			out = new ObjectOutputStream(fos);
+			out.writeObject(objectToSerialize);
+			out.close();
+		}
+		catch (IOException ex)
+		{
+			ex.printStackTrace();
+		}
+
+	}
+	
+	public static Object readObject()
+	{
+		String filename = RESOURCE_DIR  +  parseCacheFileName;
+		Object data = null;
+		FileInputStream fis = null;
+		ObjectInputStream in = null;
+		try
+		{
+			fis = new FileInputStream(filename);
+			in = new ObjectInputStream(fis);
+			data = (Object) in.readObject();
+			in.close();
+		}
+		catch (IOException ex)
+		{
+			System.out.println("Cant find parsing cache file ");
+		}
+		catch (ClassNotFoundException ex)
+		{
+			ex.printStackTrace();
+		}
+
+		return data;
+
+	}
+	
+	public class ParserObjectSer{
+		
+	}
+
+}

Modified: opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/textsimilarity/chunker2matcher/ParserChunker2MatcherProcessor.java
URL: http://svn.apache.org/viewvc/opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/textsimilarity/chunker2matcher/ParserChunker2MatcherProcessor.java?rev=1304545&r1=1304544&r2=1304545&view=diff
==============================================================================
--- opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/similarity/apps/SearchResultsProcessorTest.java (original)
+++ opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/similarity/apps/SearchResultsProcessorTest.java Fri Mar 23 18:26:39 2012
@@ -20,6 +20,7 @@ public class SearchResultsProcessorTest 
 		HitBase second = res.get(1);
 		assertTrue( second.getGenerWithQueryScore()>1.9);
 		//assertTrue(second.getTitle().indexOf("living abroad")>-1);
+		proc.close();
 				
 	}
 	
@@ -33,6 +34,6 @@ public class SearchResultsProcessorTest 
 		
 		HitBase second = res.get(1);
 		assertTrue( second.getGenerWithQueryScore()>1.9);
-				
+		proc.close();	
 	}
 }

Modified: opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/similarity/apps/SpeechRecognitionResultsProcessorTest.java
URL: http://svn.apache.org/viewvc/opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/similarity/apps/SpeechRecognitionResultsProcessorTest.java?rev=1304545&r1=1304544&r2=1304545&view=diff
==============================================================================
--- opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/similarity/apps/SpeechRecognitionResultsProcessorTest.java (original)
+++ opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/similarity/apps/SpeechRecognitionResultsProcessorTest.java Fri Mar 23 18:26:39 2012
@@ -42,6 +42,7 @@ public class SpeechRecognitionResultsPro
 				 res.get(1).getScore()> res.get(3).getScore()  && res.get(1).getScore()> res.get(4).getScore()  &&
 				 res.get(1).getScore()> res.get(5).getScore()  && res.get(1).getScore()> res.get(6).getScore()  
 				 );
+		 proc.close();
 		 
 	 }
 

Modified: opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/SyntMatcherTest.java
URL: http://svn.apache.org/viewvc/opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/SyntMatcherTest.java?rev=1304545&r1=1304544&r2=1304545&view=diff
==============================================================================
--- opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/SyntMatcherTest.java (original)
+++ opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/SyntMatcherTest.java Fri Mar 23 18:26:39 2012
@@ -75,6 +75,8 @@ public class SyntMatcherTest extends Tes
 		System.out.println(parseTreeChunk.listToString(matchResult));
 		assertEquals( " np [ [PRP-it ],  [DT-the NN-* NNS-* ]] vp [ [DT-the NN-* NNS-* ]]",
 				parseTreeChunk.listToString(matchResult));
+		
+		parserChunker2Matcher.close();
 
 	}
 
@@ -91,6 +93,7 @@ public class SyntMatcherTest extends Tes
 		System.out.println(parseTreeChunk.listToString(matchResult));
 		assertEquals(" np [ [PRP-i ],  [NN-zoom NN-camera ],  [JJ-digital NN-* ],  [NN-* IN-for ],  [NN-camera ]] vp [ [JJ-digital NN-* ],  [NN-zoom NN-camera ],  [NN-* IN-for ]]",
 				parseTreeChunk.listToString(matchResult));
+		parserChunker2Matcher.close();
 	}
 	
 	
@@ -106,6 +109,11 @@ public class SyntMatcherTest extends Tes
 		System.out.println(parseTreeChunk.listToString(matchResult));
 		assertEquals(" np [ [PRP-i ],  [NN-focus NNS-* NNS-lens IN-for JJ-digital NN-camera ],  [JJ-digital NN-camera ]] vp [ [VB-get NN-focus NNS-* NNS-lens IN-for JJ-digital NN-camera ]]",
 				parseTreeChunk.listToString(matchResult) );
-	}
+		parserChunker2Matcher.close();
+		}
+	
+	 public void testZClose(){
+		 ParserChunker2MatcherProcessor.getInstance().close();
+	 }
 
 }

Modified: opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/chunker2matcher/ParserChunker2MatcherProcessorTest.java
URL: http://svn.apache.org/viewvc/opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/chunker2matcher/ParserChunker2MatcherProcessorTest.java?rev=1304545&r1=1304544&r2=1304545&view=diff
==============================================================================
--- opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/chunker2matcher/ParserChunker2MatcherProcessorTest.java (original)
+++ opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/chunker2matcher/ParserChunker2MatcherProcessorTest.java Fri Mar 23 18:26:39 2012
@@ -9,12 +9,12 @@ import opennlp.tools.textsimilarity.Pars
 import opennlp.tools.textsimilarity.TextSimilarityBagOfWords;
 
 public class ParserChunker2MatcherProcessorTest extends TestCase{
-	private ParserChunker2MatcherProcessor parser = ParserChunker2MatcherProcessor.getInstance();
+	private ParserChunker2MatcherProcessor parser;
 	private TextSimilarityBagOfWords parserBOW = new TextSimilarityBagOfWords ();
 	private ParseTreeChunkListScorer parseTreeChunkListScorer = new ParseTreeChunkListScorer();
 
 	public void testGroupedPhrasesFormer(){
-
+		parser = ParserChunker2MatcherProcessor.getInstance();
 		String text = "Where do I apply? Go to your town office or city hall. If your town doesn't have an office, ask the town clerk or a Selectman. Tell them that you need a 1040 tax form . I Can 't Pay the Taxes on my House: What Can I Do?. Pine Tree Legal";
 
 
@@ -22,7 +22,8 @@ public class ParserChunker2MatcherProces
 		List<List<ParseTreeChunk>> res = parser.formGroupedPhrasesFromChunksForPara(text);
 		System.out.println(res);
 		assertEquals(
-				"[[NP [PRP$-your NN-town NN-office CC-or NN-city NN-hall ], NP [PRP$-your NN-town NN-doesn NN-t ], NP [DT-an NN-office ], NP [DT-the NN-town NN-clerk CC-or DT-a NNP-Selectman ], NP [DT-a NNP-Selectman ], NP [PRP-them IN-that PRP-you ], NP [PRP-you ], NP [DT-a CD-1040 NN-tax NN-form ], NP [PRP-I ], NP [DT-the NNS-Taxes IN-on PRP$-my NNP-House WP-What MD-Can PRP-I ], NP [PRP$-my NNP-House WP-What MD-Can PRP-I ], NP [WP-What MD-Can PRP-I ], NP [PRP-I ], NP [NNP-Pine NNP-Tree NNP-Legal ]], [VP [VBP-do RB-I VB-apply ], VP [VB-Go TO-to PRP$-your NN-town NN-office CC-or NN-city NN-hall ], VP [VBP-have DT-an NN-office ], VP [VB-ask DT-the NN-town NN-clerk CC-or DT-a NNP-Selectman ], VP [VB-Tell PRP-them IN-that PRP-you ], VP [VBP-need DT-a CD-1040 NN-tax NN-form ], VP [MD-Can VB-t VB-Pay DT-the NNS-Taxes IN-on PRP$-my NNP-House WP-What MD-Can PRP-I ], VP [VB-Do NNP-Pine NNP-Tree NNP-Legal ]], [PP [TO-to PRP$-your NN-town NN-office CC-or NN-city NN-hall ], PP [IN-on PRP$-my NNP-H
 ouse WP-What MD-Can PRP-I ]], [], [SENTENCE [WRB-Where VBP-do RB-I VB-apply ], SENTENCE [VB-Go TO-to PRP$-your NN-town NN-office CC-or NN-city NN-hall ], SENTENCE [IN-If PRP$-your NN-town NN-doesn NN-t VBP-have DT-an NN-office VB-ask DT-the NN-town NN-clerk CC-or DT-a NNP-Selectman ], SENTENCE [VB-Tell PRP-them IN-that PRP-you VBP-need DT-a CD-1040 NN-tax NN-form ], SENTENCE [PRP-I MD-Can VB-t VB-Pay DT-the NNS-Taxes IN-on PRP$-my NNP-House WP-What MD-Can PRP-I VB-Do NNP-Pine NNP-Tree NNP-Legal ]]]",
+			"[[NP [PRP$-your NN-town NN-office CC-or NN-city NN-hall ], NP [PRP$-your NN-town NN-doesn NN-t ], NP [DT-an NN-office ], NP [DT-the NN-town NN-clerk CC-or DT-a NNP-Selectman ], NP [DT-a NNP-Selectman ], NP [PRP-them IN-that PRP-you ], NP [PRP-you ], NP [DT-a CD-1040 NN-tax NN-form ], NP [PRP-I ], NP [DT-the NNS-Taxes IN-on PRP$-my NNP-House WP-What MD-Can PRP-I ], NP [PRP$-my NNP-House WP-What MD-Can PRP-I ], NP [WP-What MD-Can PRP-I ], NP [PRP-I ], NP [NNP-Pine NNP-Tree NNP-Legal ]], [VP [VBP-do RB-I VB-apply ], VP [VB-Go TO-to PRP$-your NN-town NN-office CC-or NN-city NN-hall ], VP [VBP-have DT-an NN-office ], VP [VB-ask DT-the NN-town NN-clerk CC-or DT-a NNP-Selectman ], VP [VB-Tell PRP-them IN-that PRP-you ], VP [VBP-need DT-a CD-1040 NN-tax NN-form ], VP [MD-Can VB-t VB-Pay DT-the NNS-Taxes IN-on PRP$-my NNP-House WP-What MD-Can PRP-I ], VP [VB-Do ]], [PP [TO-to PRP$-your NN-town NN-office CC-or NN-city NN-hall ], PP [IN-on PRP$-my NNP-House WP-What MD-Can PRP-I ]],
  [], [SENTENCE [WRB-Where VBP-do RB-I VB-apply ], SENTENCE [VB-Go TO-to PRP$-your NN-town NN-office CC-or NN-city NN-hall ], SENTENCE [IN-If PRP$-your NN-town NN-doesn NN-t VBP-have DT-an NN-office VB-ask DT-the NN-town NN-clerk CC-or DT-a NNP-Selectman ], SENTENCE [VB-Tell PRP-them IN-that PRP-you VBP-need DT-a CD-1040 NN-tax NN-form ], SENTENCE [PRP-I MD-Can VB-t VB-Pay DT-the NNS-Taxes IN-on PRP$-my NNP-House WP-What MD-Can PRP-I VB-Do ], SENTENCE [NNP-Pine NNP-Tree NNP-Legal ]]]",
+				//	"[[NP [PRP$-your NN-town NN-office CC-or NN-city NN-hall ], NP [PRP$-your NN-town NN-doesn NN-t ], NP [DT-an NN-office ], NP [DT-the NN-town NN-clerk CC-or DT-a NNP-Selectman ], NP [DT-a NNP-Selectman ], NP [PRP-them IN-that PRP-you ], NP [PRP-you ], NP [DT-a CD-1040 NN-tax NN-form ], NP [PRP-I ], NP [DT-the NNS-Taxes IN-on PRP$-my NNP-House WP-What MD-Can PRP-I ], NP [PRP$-my NNP-House WP-What MD-Can PRP-I ], NP [WP-What MD-Can PRP-I ], NP [PRP-I ], NP [NNP-Pine NNP-Tree NNP-Legal ]], [VP [VBP-do RB-I VB-apply ], VP [VB-Go TO-to PRP$-your NN-town NN-office CC-or NN-city NN-hall ], VP [VBP-have DT-an NN-office ], VP [VB-ask DT-the NN-town NN-clerk CC-or DT-a NNP-Selectman ], VP [VB-Tell PRP-them IN-that PRP-you ], VP [VBP-need DT-a CD-1040 NN-tax NN-form ], VP [MD-Can VB-t VB-Pay DT-the NNS-Taxes IN-on PRP$-my NNP-House WP-What MD-Can PRP-I ], VP [VB-Do NNP-Pine NNP-Tree NNP-Legal ]], [PP [TO-to PRP$-your NN-town NN-office CC-or NN-city NN-hall ], PP [IN-on PRP$-my NN
 P-House WP-What MD-Can PRP-I ]], [], [SENTENCE [WRB-Where VBP-do RB-I VB-apply ], SENTENCE [VB-Go TO-to PRP$-your NN-town NN-office CC-or NN-city NN-hall ], SENTENCE [IN-If PRP$-your NN-town NN-doesn NN-t VBP-have DT-an NN-office VB-ask DT-the NN-town NN-clerk CC-or DT-a NNP-Selectman ], SENTENCE [VB-Tell PRP-them IN-that PRP-you VBP-need DT-a CD-1040 NN-tax NN-form ], SENTENCE [PRP-I MD-Can VB-t VB-Pay DT-the NNS-Taxes IN-on PRP$-my NNP-House WP-What MD-Can PRP-I VB-Do NNP-Pine NNP-Tree NNP-Legal ]]]",
 				res.toString());
 
 		res = parser.formGroupedPhrasesFromChunksForSentence("How can I get short focus zoom lens for digital camera");
@@ -42,13 +43,21 @@ public class ParserChunker2MatcherProces
 		assertEquals(
 				"[[NP [NNP-UN NNP-Ambassador NNP-Ron NNP-Prosor ], NP [DT-the JJ-Israeli NN-position IN-that DT-the JJ-only NN-way DT-the NNPS-Palestinians ], NP [DT-the JJ-only NN-way DT-the NNPS-Palestinians ], NP [DT-the NNPS-Palestinians ], NP [NN-membership CC-and NN-statehood VBZ-is IN-through JJ-direct NNS-negotiations IN-with DT-the NNP-Israelis IN-on DT-a JJ-comprehensive NN-peace NN-agreement ], NP [JJ-direct NNS-negotiations IN-with DT-the NNP-Israelis IN-on DT-a JJ-comprehensive NN-peace NN-agreement ], NP [DT-the NNP-Israelis IN-on DT-a JJ-comprehensive NN-peace NN-agreement ], NP [DT-a JJ-comprehensive NN-peace NN-agreement ]], [VP [VBD-repeated DT-the JJ-Israeli NN-position IN-that DT-the JJ-only NN-way DT-the NNPS-Palestinians ], VP [MD-will VB-get IN-UN NN-membership CC-and NN-statehood VBZ-is IN-through JJ-direct NNS-negotiations IN-with DT-the NNP-Israelis IN-on DT-a JJ-comprehensive NN-peace NN-agreement ]], [PP [IN-that DT-the JJ-only NN-way DT-the NNPS-Palestinians
  ], PP [IN-UN NN-membership CC-and NN-statehood VBZ-is IN-through JJ-direct NNS-negotiations IN-with DT-the NNP-Israelis IN-on DT-a JJ-comprehensive NN-peace NN-agreement ], PP [IN-through JJ-direct NNS-negotiations IN-with DT-the NNP-Israelis IN-on DT-a JJ-comprehensive NN-peace NN-agreement ], PP [IN-with DT-the NNP-Israelis IN-on DT-a JJ-comprehensive NN-peace NN-agreement ], PP [IN-on DT-a JJ-comprehensive NN-peace NN-agreement ]], [], [SENTENCE [NNP-UN NNP-Ambassador NNP-Ron NNP-Prosor VBD-repeated DT-the JJ-Israeli NN-position IN-that DT-the JJ-only NN-way DT-the NNPS-Palestinians MD-will VB-get IN-UN NN-membership CC-and NN-statehood VBZ-is IN-through JJ-direct NNS-negotiations IN-with DT-the NNP-Israelis IN-on DT-a JJ-comprehensive NN-peace NN-agreement ]]]",
 				res.toString());
+		parser.close();
 	}
 
 	public void testPrintParseTree(){
-		parser.printParseTree("How can I get short focus zoom lens for digital camera");
+		parser = ParserChunker2MatcherProcessor.getInstance();
+		try {
+			parser.printParseTree("How can I get short focus zoom lens for digital camera");
+		} catch (Exception e) {
+			// when models does not read
+		}
+		parser.close();
 	}
 
 	public void testRelevanceAssessm(){
+		parser = ParserChunker2MatcherProcessor.getInstance();
 		String phrase1 = "Its classy design and the Mercedes name make it a very cool vehicle to drive. "
 			+ "The engine makes it a powerful car. "
 			+ "The strong engine gives it enough power. "
@@ -58,10 +67,12 @@ public class ParserChunker2MatcherProces
 			+ "This car provides you a very good mileage.";
 
 		System.out.println(parser.assessRelevance(phrase1, phrase2).getMatchResult());
+		parser.close();
 
 	}
 
 	public void testCompareRelevanceAssessmWithBagOfWords(){
+		parser = ParserChunker2MatcherProcessor.getInstance();
 		// we first demonstrate how similarity expression for DIFFERENT cases have too high score for bagOfWords
 		String phrase1 = "How to deduct rental expense from income ";
 		String phrase2 = "How to deduct repair expense from rental income.";
@@ -85,6 +96,7 @@ public class ParserChunker2MatcherProces
 		bagOfWordsScore = parserBOW.assessRelevanceAndGetScore(phrase1, phrase2);
 		assertTrue(matchScore > 2*bagOfWordsScore);
 		System.out.println("MatchScore is adequate ( = "+matchScore + ") and bagOfWordsScore = "+bagOfWordsScore+" is too low");
+		parser.close();
 
 	}
 }

Modified: opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/chunker2matcher/PhraseNodeTest.java
URL: http://svn.apache.org/viewvc/opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/chunker2matcher/PhraseNodeTest.java?rev=1304545&r1=1304544&r2=1304545&view=diff
==============================================================================
--- opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/chunker2matcher/PhraseNodeTest.java (original)
+++ opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/textsimilarity/chunker2matcher/PhraseNodeTest.java Fri Mar 23 18:26:39 2012
@@ -9,17 +9,22 @@ public class PhraseNodeTest extends Test
     public void testPOSTagsExtraction(){
     	
     	SentenceNode node  = proc.parseSentenceNode("How can I get there");
-		List<String> pOSlist = node.getOrderedPOSList();
-		assertEquals("[WRB, MD, PRP, VB, RB]", pOSlist.toString());
-		
-		node  = proc.parseSentenceNode("where do I apply");
-		pOSlist = node.getOrderedPOSList();
-		assertEquals("[WRB, VBP, PRP, RB]", pOSlist.toString());
-		
-		// should NOT start with upper case! last tag is missing
-		node  = proc.parseSentenceNode("Where do I apply");
-		pOSlist = node.getOrderedPOSList();
-		assertEquals("[WRB, VBP, PRP]", pOSlist.toString());
+    	
+		try {
+			List<String> pOSlist = node.getOrderedPOSList();
+			assertEquals("[WRB, MD, PRP, VB, RB]", pOSlist.toString());
+			
+			node  = proc.parseSentenceNode("where do I apply");
+			pOSlist = node.getOrderedPOSList();
+			assertEquals("[WRB, VBP, PRP, RB]", pOSlist.toString());
+			
+			// should NOT start with upper case! last tag is missing
+			node  = proc.parseSentenceNode("Where do I apply");
+			pOSlist = node.getOrderedPOSList();
+			assertEquals("[WRB, VBP, PRP]", pOSlist.toString());
+		} catch (Exception e) { // for run without models, where init fails
+			assertEquals(node, null);
+		}
     }
     	
 }
--- opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/textsimilarity/chunker2matcher/ParserChunker2MatcherProcessor.java (original)
+++ opennlp/sandbox/opennlp-similarity/src/main/java/opennlp/tools/textsimilarity/chunker2matcher/ParserChunker2MatcherProcessor.java Fri Mar 23 18:26:39 2012
@@ -38,7 +38,9 @@ import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
@@ -71,8 +73,8 @@ public class ParserChunker2MatcherProces
 	protected static final int MIN_SENTENCE_LENGTH = 10;
 	private static final String MODEL_DIR_KEY = "nlp.models.dir";
 	// TODO config
-	// this is where resources shoudl live
-	private static String MODEL_DIR = "resources/models";
+	// this is where resources should live
+	private static String MODEL_DIR, MODEL_DIR_REL = "resources/models111";
 	protected static ParserChunker2MatcherProcessor instance;
 
 	private SentenceDetector sentenceDetector;
@@ -82,16 +84,39 @@ public class ParserChunker2MatcherProces
 	private ChunkerME chunker;
 	private final int NUMBER_OF_SECTIONS_IN_SENTENCE_CHUNKS = 5;
 	private static Logger LOG = Logger.getLogger("opennlp.tools.textsimilarity.chunker2matcher.ParserChunker2MatcherProcessor");
+	private Map<String,String[][]> sentence_parseObject = new HashMap<String,String[][]>();
 
+	@SuppressWarnings("unchecked")
 	protected ParserChunker2MatcherProcessor() {
-		MODEL_DIR = new File(".").getAbsolutePath().replace(".", "")+MODEL_DIR;
-		initializeSentenceDetector();
-		initializeTokenizer();
-		initializePosTagger();
-		initializeParser();
-		initializeChunker();
+		try {
+			sentence_parseObject = (Map<String,String[][]>)ParserCacheSerializer.readObject();
+		} catch (Exception e) {
+			// this file might not exist initially
+			LOG.fine("parsing  cache file does not exist (but should be created)");
+			sentence_parseObject = new HashMap<String,String[][]>();
+		}
+		if (sentence_parseObject == null)
+			sentence_parseObject = new HashMap<String,String[][]>();
+
+		try {
+			MODEL_DIR = new File(".").getAbsolutePath().replace(".", "")+MODEL_DIR_REL;
+			initializeSentenceDetector();
+			initializeTokenizer();
+			initializePosTagger();
+			initializeParser();
+			initializeChunker();
+		} catch (Exception e) {
+			LOG.fine("model cant be read and we rely on cache");
+		}
+	}
+	
+	// closing the processor, clearing loaded ling models and serializing parsing cache 
+	public void close(){
+		instance=null;
+		ParserCacheSerializer.writeObject(sentence_parseObject);
 	}
 
+
 	/**
 	 * singleton method of instantiating the processor
 	 * @return the instance
@@ -215,6 +240,57 @@ public class ParserChunker2MatcherProces
 		}
 		return listOfChunksAccum;
 	}
+	
+	String[][] parseChunkSentence(String sentenceInp){
+		String[][] resToksTags = sentence_parseObject.get(sentenceInp);
+		if ( resToksTags!=null)
+			return resToksTags;
+		if(tokenizer == null)
+			return null;
+		
+		String sentence = TextProcessor.removePunctuation(sentenceInp);
+	
+		String[] toks = tokenizer.tokenize(sentence);
+		String[] tags = new String[toks.length]; //posTagger.tag(toks);
+		SentenceNode node  = parseSentenceNode(sentence);
+		if (node==null){
+			LOG.info("Problem parsing sentence '"+sentence);
+			return null;
+		}
+		List<String> POSlist = node.getOrderedPOSList();
+		
+		tags = POSlist.toArray(new String[0]);
+		if (toks.length != tags.length){
+			LOG.info("disagreement between toks and tags; sent =  '"+sentence + "'\n tags = "+tags + 
+					"\n will now try this sentence in lower case" );
+			node  = parseSentenceNode(sentence.toLowerCase());
+			if (node==null){
+				LOG.info("Problem parsing sentence '"+sentence);
+				return null;
+			}
+			POSlist = node.getOrderedPOSList();
+			tags = POSlist.toArray(new String[0]);
+			if (toks.length != tags.length){
+				LOG.info("AGAIN: disagreement between toks and tags for lower case! ");
+				if (toks.length>tags.length){
+					String[] newToks = new String[tags.length];
+					for(int i = 0; i<tags.length; i++ ){
+						newToks[i] = toks[i];
+					}
+					toks = newToks;
+					
+				} else
+					return null;
+			}
+		} 
+		
+		String[] res = chunker.chunk(toks, tags);
+		String[][] resTagToks = new String[][] { res, tags, toks};
+		sentence_parseObject.put(sentenceInp,  resTagToks);		
+		return resTagToks;
+	}
+	
+	
 
 	/**
 	 * 
@@ -224,7 +300,7 @@ public class ParserChunker2MatcherProces
 	public synchronized List<List<ParseTreeChunk>> formGroupedPhrasesFromChunksForSentence(String sentence) {
 		if (sentence == null || sentence.trim().length() < MIN_SENTENCE_LENGTH)
 			return null;
-
+   /*  
 		sentence = TextProcessor.removePunctuation(sentence);
 
 		String[] toks = tokenizer.tokenize(sentence);
@@ -259,8 +335,16 @@ public class ParserChunker2MatcherProces
 				} else
 					return null;
 			}
-		}
-		String[] res = chunker.chunk(toks, tags);
+		} 
+	*/	
+		String[][] resTagToks = parseChunkSentence(sentence);
+		if (resTagToks == null )
+			return null;
+		String[] res = resTagToks[0];
+		String[] tags = resTagToks[1];
+		String[] toks = resTagToks[2];
+		
+	//	String[] res = chunker.chunk(toks, tags);
 	
 		List<List<ParseTreeChunk>> listOfChunks = new ArrayList<List<ParseTreeChunk>>();
 		List<ParseTreeChunk> nounPhr = new ArrayList<ParseTreeChunk>(), 
@@ -470,8 +554,13 @@ public class ParserChunker2MatcherProces
 	public String[] splitSentences(String text) {
 		if (text == null)
 			return null;
-
-		return sentenceDetector.sentDetect(text);
+	//	if (sentenceDetector!=null)
+	//		return sentenceDetector.sentDetect(text);
+		else 
+		{
+			List<String> sents = TextProcessor.splitToSentences(text);
+			return sents.toArray(new String[0]);
+		}
 	}
 
 	public String[] tokenizeSentence(String sentence) {

Modified: opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/similarity/apps/SearchResultsProcessorTest.java
URL: http://svn.apache.org/viewvc/opennlp/sandbox/opennlp-similarity/src/test/java/opennlp/tools/similarity/apps/SearchResultsProcessorTest.java?rev=1304545&r1=1304544&r2=1304545&view=diff
==============================================================================